@@ -58,10 +58,10 @@
 #' @param impute.value [\code{character(1)}]\cr
 #'   Factor missing values will be replaced by \code{impute.value}. Default is \code{missing}.
 #' @param scale [\code{character(1)}]\cr
-#'   Parameter \code{scale} from the function \code{GGally::ggparcoord} which is used for
+#'   Parameter \code{scale} from the function \code{\link[GGally]{ggparcoord}} which is used for
 #'   the multiD-case. Default is \code{std}.
 #' @param ggplot.theme
-#'   Theme for the ggplots. Can be generated by \code{ggplot2::theme()}. Default is
+#'   Theme for the ggplots. Can be generated by \code{\link[ggplot2]{theme}}. Default is
 #'   \code{ggplot2::theme(legend.position = "top")}.
 #' @param marked [\code{integer} | \code{character(1)} | NULL]\cr
 #'    \dQuote{best} or indices of points that should be marked in the plots.
@@ -101,7 +101,7 @@ renderOptPathPlot = function(op, iter, x.over.time, y.over.time, contour.name =
   impute.value = "missing", scale = "std", ggplot.theme = ggplot2::theme(legend.position = "top"),
   marked = NULL, subset.obs, subset.vars, subset.targets, short.x.names, short.y.names, short.rest.names) {
 
-  requirePackages(c("GGally", "ggplot2"), why = "renderOptPathPlot")
+  requirePackages(c("GGally", "ggplot2"), why = "renderOptPathPlot", default.method = "load")
 
   iters.max = max(getOptPathDOB(op))
   assertClass(op, "OptPath")
